@@ -83,6 +83,10 @@ class PlotTemplate:
     WEEKLY_INDICATORS = []
     EXCESS_INDICATORS = []
 
+    @property
+    def geometric_excess_returns(self):
+        return self.p_nav / self.b_nav - 1
+
 
 class DefaultPlot(PlotTemplate):
     """ 基础 """
@@ -137,10 +141,6 @@ class DefaultPlot(PlotTemplate):
         IndicatorInfo("weekly_excess_ulcer_performance_index", _("WeeklyExcessUlcerPerformanceIndex"), BLACK, "{0:.4}", 11, 1.4),
     ]]
 
-    @property
-    def excess_returns(self):
-        return self.p_nav - self.b_nav
-
 
 class RiceQuant(PlotTemplate):
     # 指标的宽高
@@ -184,12 +184,6 @@ class RiceQuant(PlotTemplate):
 
     WEEKLY_INDICATORS = []
 
-    @property
-    def excess_returns(self):
-        p_return = (self.p_nav / self.p_nav.shift(1).fillna(1)).fillna(0) - 1
-        b_return = (self.b_nav / self.b_nav.shift(1).fillna(1)).fillna(0) - 1
-        return ((p_return - b_return) + 1).cumprod() - 1
-
 
 PLOT_TEMPLATE: dict = {
     "default": DefaultPlot,
