@@ -422,7 +422,7 @@ class Instrument(metaclass=PropertyReprMeta):
         return ipo_days if ipo_days >= 0 else -1
 
     def days_to_expire(self):
-        if self.type != 'Future' or self.order_book_id[-2:] == '88' or self.order_book_id[-2:] == '99':
+        if self.type != 'Future' or self.is_future_continuous_contract(self.order_book_id):
             return -1
 
         date = Environment.get_instance().trading_dt.date()
@@ -450,12 +450,13 @@ class Instrument(metaclass=PropertyReprMeta):
         else:
             raise NotImplementedError
 
-    FUTURE_CONTINUOUS_CONTRACT = re.compile("^[A-Z]+(88|888|99|889)$")
+    FUTURE_CONTINUOUS_CONTRACT = re.compile(r"^[A-Z]+(88|888|99|889)([A-Z]\d+)?$")
 
     @classmethod
     def is_future_continuous_contract(cls, order_book_id):
         return re.match(cls.FUTURE_CONTINUOUS_CONTRACT, order_book_id)
 
+
 class SectorCodeItem(object):
     def __init__(self, cn, en, name):
         self.__cn = cn
